@@ -630,7 +630,8 @@ sub item_selected {
             $i++;
 
             $form->{"qty_$i"}      = $qty;
-            $form->{"discount_$i"} = $form->{discount} * 100;
+            # We should unset this since it is pulling from the customer/vendor
+            # $form->{"discount_$i"} = $form->{discount};
             $form->{"reqdate_$i"}  = $form->{reqdate}
               if $form->{type} !~ /_quotation/;
 
