@@ -84,17 +84,9 @@ GRANT SELECT ON eca_to_contact TO "lsmb_<?lsmb dbname ?>__contact_read";
 GRANT EXECUTE ON FUNCTION eca__list_notes(int)  TO "lsmb_<?lsmb dbname ?>__contact_read";
 
 
-INSERT INTO menu_acl (node_id, acl_type, role_name) 
-values (1, 'allow', 'lsmb_<?lsmb dbname ?>__contact_read');
-INSERT INTO menu_acl (node_id, acl_type, role_name) 
-values (11, 'allow', 'lsmb_<?lsmb dbname ?>__contact_read');
 INSERT INTO menu_acl (node_id, acl_type, role_name) 
 values (14, 'allow', 'lsmb_<?lsmb dbname ?>__contact_read');
 INSERT INTO menu_acl (node_id, acl_type, role_name) 
-values (21, 'allow', 'lsmb_<?lsmb dbname ?>__contact_read');
-INSERT INTO menu_acl (node_id, acl_type, role_name) 
-values (30, 'allow', 'lsmb_<?lsmb dbname ?>__contact_read');
-INSERT INTO menu_acl (node_id, acl_type, role_name) 
 values (33, 'allow', 'lsmb_<?lsmb dbname ?>__contact_read');
 
 DELETE FROM menu_acl
@@ -143,17 +135,9 @@ GRANT ALL ON customertax TO"lsmb_<?lsmb dbname ?>__contact_create";
 GRANT ALL ON vendortax TO"lsmb_<?lsmb dbname ?>__contact_create";
 
 
-INSERT INTO menu_acl (node_id, acl_type, role_name) 
-values (1, 'allow', 'lsmb_<?lsmb dbname ?>__contact_create');
-INSERT INTO menu_acl (node_id, acl_type, role_name) 
-values (11, 'allow', 'lsmb_<?lsmb dbname ?>__contact_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name) 
 values (12, 'allow', 'lsmb_<?lsmb dbname ?>__contact_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name) 
-values (21, 'allow', 'lsmb_<?lsmb dbname ?>__contact_create');
-INSERT INTO menu_acl (node_id, acl_type, role_name) 
-values (30, 'allow', 'lsmb_<?lsmb dbname ?>__contact_create');
-INSERT INTO menu_acl (node_id, acl_type, role_name) 
 values (31, 'allow', 'lsmb_<?lsmb dbname ?>__contact_create');
 
 
@@ -247,8 +231,6 @@ GRANT ALL ON id TO "lsmb_<?lsmb dbname ?>__ar_transaction_create";
 GRANT INSERT ON acc_trans TO "lsmb_<?lsmb dbname ?>__ar_transaction_create";
 GRANT ALL ON acc_trans_entry_id_seq TO "lsmb_<?lsmb dbname ?>__ar_transaction_create";
 INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (1, 'allow', 'lsmb_<?lsmb dbname ?>__ar_transaction_create');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (2, 'allow', 'lsmb_<?lsmb dbname ?>__ar_transaction_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (194, 'allow', 'lsmb_<?lsmb dbname ?>__ar_transaction_create');
@@ -263,8 +245,6 @@ GRANT ALL ON id TO "lsmb_<?lsmb dbname ?>__ar_transaction_create_voucher";
 GRANT INSERT ON acc_trans TO "lsmb_<?lsmb dbname ?>__ar_transaction_create_voucher";
 GRANT ALL ON acc_trans_entry_id_seq TO "lsmb_<?lsmb dbname ?>__ar_transaction_create_voucher";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (4, 'allow', 'lsmb_<?lsmb dbname ?>__ar_transaction_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name) 
 values (198, 'allow', 'lsmb_<?lsmb dbname ?>__ar_transaction_create_voucher');
 
@@ -312,10 +292,6 @@ GRANT SELECT ON invoice TO "lsmb_<?lsmb dbname ?>__ar_transaction_list";
 GRANT SELECT ON inventory TO "lsmb_<?lsmb dbname ?>__ar_transaction_list";
 GRANT SELECT ON tax_extended TO "lsmb_<?lsmb dbname ?>__ar_transaction_list";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (1, 'allow', 'lsmb_<?lsmb dbname ?>__ar_transaction_list');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (4, 'allow', 'lsmb_<?lsmb dbname ?>__ar_transaction_list');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (5, 'allow', 'lsmb_<?lsmb dbname ?>__ar_transaction_list');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
@@ -327,10 +303,6 @@ values (9, 'allow', 'lsmb_<?lsmb dbname ?>__ar_transaction_list');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (10, 'allow', 'lsmb_<?lsmb dbname ?>__ar_transaction_list');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (11, 'allow', 'lsmb_<?lsmb dbname ?>__ar_transaction_list');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (13, 'allow', 'lsmb_<?lsmb dbname ?>__ar_transaction_list');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (15, 'allow', 'lsmb_<?lsmb dbname ?>__ar_transaction_list');
 
 --CREATE ROLE "lsmb_<?lsmb dbname ?>__ar_voucher_all"
@@ -354,14 +326,12 @@ GRANT "lsmb_<?lsmb dbname ?>__exchangerate_edit"
    TO "lsmb_<?lsmb dbname ?>__sales_order_create";
 
 
-GRANT INSERT, UPDATE ON oe TO "lsmb_<?lsmb dbname ?>__sales_order_create";
+GRANT ALL ON oe TO "lsmb_<?lsmb dbname ?>__sales_order_create";
 GRANT ALL ON oe_id_seq TO "lsmb_<?lsmb dbname ?>__sales_order_create";
-GRANT INSERT, UPDATE ON orderitems TO "lsmb_<?lsmb dbname ?>__sales_order_create";
+GRANT ALL ON orderitems TO "lsmb_<?lsmb dbname ?>__sales_order_create";
 GRANT ALL ON orderitems_id_seq TO "lsmb_<?lsmb dbname ?>__sales_order_create";
 GRANT ALL on inventory TO "lsmb_<?lsmb dbname ?>__sales_order_create";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (50, 'allow', 'lsmb_<?lsmb dbname ?>__sales_order_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (51, 'allow', 'lsmb_<?lsmb dbname ?>__sales_order_create');
 
@@ -377,13 +347,11 @@ IN ROLE "lsmb_<?lsmb dbname ?>__contact_read";
 GRANT "lsmb_<?lsmb dbname ?>__exchangerate_edit"
    TO "lsmb_<?lsmb dbname ?>__sales_quotation_create";
 
-GRANT INSERT, UPDATE ON oe TO "lsmb_<?lsmb dbname ?>__sales_quotation_create";
+GRANT ALL ON oe TO "lsmb_<?lsmb dbname ?>__sales_quotation_create";
 GRANT ALL ON oe_id_seq TO "lsmb_<?lsmb dbname ?>__sales_quotation_create";
 GRANT INSERT, UPDATE ON orderitems TO "lsmb_<?lsmb dbname ?>__sales_quotation_create";
 GRANT ALL ON orderitems_id_seq TO "lsmb_<?lsmb dbname ?>__sales_quotation_create";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (67, 'allow', 'lsmb_<?lsmb dbname ?>__sales_quotation_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (68, 'allow', 'lsmb_<?lsmb dbname ?>__sales_quotation_create');
 
@@ -396,10 +364,6 @@ IN ROLE "lsmb_<?lsmb dbname ?>__contact_read",
 GRANT SELECT ON oe TO "lsmb_<?lsmb dbname ?>__sales_order_list";
 GRANT SELECT ON orderitems TO "lsmb_<?lsmb dbname ?>__sales_order_list";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (50, 'allow', 'lsmb_<?lsmb dbname ?>__sales_order_list');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (53, 'allow', 'lsmb_<?lsmb dbname ?>__sales_order_list');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (54, 'allow', 'lsmb_<?lsmb dbname ?>__sales_order_list');
 
@@ -412,10 +376,6 @@ IN ROLE "lsmb_<?lsmb dbname ?>__contact_read",
 GRANT SELECT ON oe TO "lsmb_<?lsmb dbname ?>__sales_quotation_list";
 GRANT SELECT ON orderitems TO "lsmb_<?lsmb dbname ?>__sales_quotation_list";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (67, 'allow', 'lsmb_<?lsmb dbname ?>__sales_quotation_list');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (70, 'allow', 'lsmb_<?lsmb dbname ?>__sales_quotation_list');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (71, 'allow', 'lsmb_<?lsmb dbname ?>__sales_quotation_list');
 
@@ -449,8 +409,6 @@ GRANT ALL ON acc_trans_entry_id_seq TO "lsmb_<?lsmb dbname ?>__ap_transaction_cr
 
 GRANT SELECT ON oe TO "lsmb_<?lsmb dbname ?>__ap_transaction_create";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (21, 'allow', 'lsmb_<?lsmb dbname ?>__ap_transaction_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (22, 'allow', 'lsmb_<?lsmb dbname ?>__ap_transaction_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
@@ -511,10 +469,6 @@ GRANT SELECT ON invoice TO "lsmb_<?lsmb dbname ?>__ap_transaction_list";
 GRANT SELECT ON inventory TO "lsmb_<?lsmb dbname ?>__ap_transaction_list";
 GRANT SELECT ON tax_extended TO "lsmb_<?lsmb dbname ?>__ap_transaction_list";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (21, 'allow', 'lsmb_<?lsmb dbname ?>__ap_transaction_list');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (24, 'allow', 'lsmb_<?lsmb dbname ?>__ap_transaction_list');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (25, 'allow', 'lsmb_<?lsmb dbname ?>__ap_transaction_list');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
@@ -526,10 +480,6 @@ values (28, 'allow', 'lsmb_<?lsmb dbname ?>__ap_transaction_list');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (29, 'allow', 'lsmb_<?lsmb dbname ?>__ap_transaction_list');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (30, 'allow', 'lsmb_<?lsmb dbname ?>__ap_transaction_list');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (32, 'allow', 'lsmb_<?lsmb dbname ?>__ap_transaction_list');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (34, 'allow', 'lsmb_<?lsmb dbname ?>__ap_transaction_list');
 
 
@@ -548,12 +498,19 @@ CREATE ROLE "lsmb_<?lsmb dbname ?>__purchase_order_create"
 WITH INHERIT NOLOGIN
 IN ROLE "lsmb_<?lsmb dbname ?>__contact_read";
 
+CREATE ROLE "lsmb_<?lsmb dbname ?>__ap_transaction_all"
+WITH INHERIT NOLOGIN
+IN ROLE "lsmb_<?lsmb dbname ?>__ap_transaction_create",
+"lsmb_<?lsmb dbname ?>__ap_invoice_create",
+"lsmb_<?lsmb dbname ?>__ap_transaction_list",
+"lsmb_<?lsmb dbname ?>__file_attach_tx";
+
 -- Role created later; using the GRANT construct, we support upgrades
 GRANT "lsmb_<?lsmb dbname ?>__exchangerate_edit"
    TO "lsmb_<?lsmb dbname ?>__purchase_order_create";
 
-GRANT INSERT, UPDATE ON oe TO "lsmb_<?lsmb dbname ?>__purchase_order_create";
-GRANT INSERT, UPDATE ON orderitems TO "lsmb_<?lsmb dbname ?>__purchase_order_create";
+GRANT ALL ON oe TO "lsmb_<?lsmb dbname ?>__purchase_order_create";
+GRANT ALL ON orderitems TO "lsmb_<?lsmb dbname ?>__purchase_order_create";
 GRANT ALL ON oe_id_seq TO "lsmb_<?lsmb dbname ?>__purchase_order_create";
 GRANT ALL ON orderitems_id_seq TO "lsmb_<?lsmb dbname ?>__purchase_order_create";
 GRANT ALL on inventory TO "lsmb_<?lsmb dbname ?>__purchase_order_create";
@@ -562,8 +519,6 @@ CREATE ROLE "lsmb_<?lsmb dbname ?>__purchase_order_edit";
 GRANT DELETE ON orderitems TO "lsmb_<?lsmb dbname ?>__purchase_order_edit";
 GRANT DELETE ON new_shipto TO "lsmb_<?lsmb dbname ?>__purchase_order_edit";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (50, 'allow', 'lsmb_<?lsmb dbname ?>__purchase_order_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (52, 'allow', 'lsmb_<?lsmb dbname ?>__purchase_order_create');
 
@@ -576,13 +531,11 @@ IN ROLE "lsmb_<?lsmb dbname ?>__contact_read";
 GRANT "lsmb_<?lsmb dbname ?>__exchangerate_edit"
    TO "lsmb_<?lsmb dbname ?>__rfq_create";
 
-GRANT INSERT, UPDATE ON oe TO "lsmb_<?lsmb dbname ?>__rfq_create";
-GRANT INSERT, UPDATE ON orderitems TO "lsmb_<?lsmb dbname ?>__rfq_create";
+GRANT ALL ON oe TO "lsmb_<?lsmb dbname ?>__rfq_create";
+GRANT ALL ON orderitems TO "lsmb_<?lsmb dbname ?>__rfq_create";
 GRANT ALL ON oe_id_seq TO "lsmb_<?lsmb dbname ?>__rfq_create";
 GRANT ALL ON orderitems_id_seq TO "lsmb_<?lsmb dbname ?>__rfq_create";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (67, 'allow', 'lsmb_<?lsmb dbname ?>__rfq_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (69, 'allow', 'lsmb_<?lsmb dbname ?>__rfq_create');
 
@@ -594,10 +547,6 @@ IN ROLE "lsmb_<?lsmb dbname ?>__contact_read";
 GRANT SELECT ON oe TO "lsmb_<?lsmb dbname ?>__purchase_order_list";
 GRANT SELECT ON orderitems TO "lsmb_<?lsmb dbname ?>__purchase_order_list";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (50, 'allow', 'lsmb_<?lsmb dbname ?>__purchase_order_list');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (53, 'allow', 'lsmb_<?lsmb dbname ?>__purchase_order_list');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (55, 'allow', 'lsmb_<?lsmb dbname ?>__purchase_order_list');
 
@@ -609,10 +558,6 @@ IN ROLE "lsmb_<?lsmb dbname ?>__contact_read";
 GRANT SELECT ON oe TO "lsmb_<?lsmb dbname ?>__rfq_list";
 GRANT SELECT ON orderitems TO "lsmb_<?lsmb dbname ?>__rfq_list";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (67, 'allow', 'lsmb_<?lsmb dbname ?>__rfq_list');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (70, 'allow', 'lsmb_<?lsmb dbname ?>__rfq_list');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (72, 'allow', 'lsmb_<?lsmb dbname ?>__rfq_list');
 
@@ -645,8 +590,6 @@ TO "lsmb_<?lsmb dbname ?>__reconciliation_enter";
 
  GRANT ALL ON cr_report_id_seq TO "lsmb_<?lsmb dbname ?>__reconciliation_enter";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (35, 'allow', 'lsmb_<?lsmb dbname ?>__reconciliation_enter');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (45, 'allow', 'lsmb_<?lsmb dbname ?>__reconciliation_enter');
 
@@ -665,10 +608,6 @@ GRANT UPDATE ON cr_report TO "lsmb_<?lsmb dbname ?>__reconciliation_approve";
 GRANT SELECT ON acc_trans, account_checkpoint TO 
 "lsmb_<?lsmb dbname ?>__reconciliation_approve";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (35, 'allow', 'lsmb_<?lsmb dbname ?>__reconciliation_approve');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (41, 'allow', 'lsmb_<?lsmb dbname ?>__reconciliation_approve');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (44, 'allow', 'lsmb_<?lsmb dbname ?>__reconciliation_approve');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
@@ -695,8 +634,6 @@ GRANT ALL ON payment, payment_id_seq TO "lsmb_<?lsmb dbname ?>__payment_process"
 
 
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (35, 'allow', 'lsmb_<?lsmb dbname ?>__payment_process');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (38, 'allow', 'lsmb_<?lsmb dbname ?>__payment_process');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
@@ -720,8 +657,6 @@ GRANT INSERT ON acc_trans TO "lsmb_<?lsmb dbname ?>__receipt_process";
 GRANT ALL ON acc_trans_entry_id_seq TO "lsmb_<?lsmb dbname ?>__receipt_process";
 GRANT UPDATE ON ar TO "lsmb_<?lsmb dbname ?>__receipt_process";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (35, 'allow', 'lsmb_<?lsmb dbname ?>__receipt_process');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (36, 'allow', 'lsmb_<?lsmb dbname ?>__receipt_process');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
@@ -729,8 +664,6 @@ values (37, 'allow', 'lsmb_<?lsmb dbname ?>__receipt_process');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (42, 'allow', 'lsmb_<?lsmb dbname ?>__receipt_process');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (47, 'allow', 'lsmb_<?lsmb dbname ?>__receipt_process');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (203, 'allow', 'lsmb_<?lsmb dbname ?>__receipt_process');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (204, 'allow', 'lsmb_<?lsmb dbname ?>__receipt_process');
@@ -752,8 +685,10 @@ GRANT INSERT ON parts, makemodel, partsgroup, assembly TO "lsmb_<?lsmb dbname ?>
 GRANT ALL ON parts_id_seq, partsgroup_id_seq TO "lsmb_<?lsmb dbname ?>__part_create";
 GRANT INSERT ON partstax TO "lsmb_<?lsmb dbname ?>__part_create";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (77, 'allow', 'lsmb_<?lsmb dbname ?>__part_create');
+GRANT ALL ON partsvendor_entry_id_seq, partscustomer_entry_id_seq
+TO "lsmb_<?lsmb dbname ?>__part_create", 
+   "lsmb_<?lsmb dbname ?>__contact_create";
+
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (78, 'allow', 'lsmb_<?lsmb dbname ?>__part_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
@@ -783,10 +718,6 @@ GRANT ALL ON makemodel TO "lsmb_<?lsmb dbname ?>__part_edit";
 --###oldcode: Should have been UPDATE
 GRANT ALL ON partstax TO "lsmb_<?lsmb dbname ?>__part_edit";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (77, 'allow', 'lsmb_<?lsmb dbname ?>__part_edit');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (85, 'allow', 'lsmb_<?lsmb dbname ?>__part_edit');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (86, 'allow', 'lsmb_<?lsmb dbname ?>__part_edit');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
@@ -812,10 +743,6 @@ GRANT SELECT ON inventory TO "lsmb_<?lsmb dbname ?>__inventory_reports";
 GRANT SELECT ON invoice TO "lsmb_<?lsmb dbname ?>__inventory_reports";
 GRANT SELECT ON acc_trans TO "lsmb_<?lsmb dbname ?>__inventory_reports";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (77, 'allow', 'lsmb_<?lsmb dbname ?>__inventory_reports');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (85, 'allow', 'lsmb_<?lsmb dbname ?>__inventory_reports');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (88, 'allow', 'lsmb_<?lsmb dbname ?>__inventory_reports');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
@@ -830,8 +757,6 @@ GRANT INSERT ON pricegroup TO "lsmb_<?lsmb dbname ?>__pricegroup_create";
 GRANT ALL ON pricegroup_id_seq TO "lsmb_<?lsmb dbname ?>__pricegroup_create";
 GRANT UPDATE ON entity_credit_account TO "lsmb_<?lsmb dbname ?>__pricegroup_create";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (77, 'allow', 'lsmb_<?lsmb dbname ?>__pricegroup_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (83, 'allow', 'lsmb_<?lsmb dbname ?>__pricegroup_create');
 
@@ -843,10 +768,6 @@ IN ROLE "lsmb_<?lsmb dbname ?>__contact_read";
 GRANT UPDATE ON pricegroup TO "lsmb_<?lsmb dbname ?>__pricegroup_edit";
 GRANT UPDATE ON entity_credit_account TO "lsmb_<?lsmb dbname ?>__pricegroup_edit";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (77, 'allow', 'lsmb_<?lsmb dbname ?>__pricegroup_edit');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (85, 'allow', 'lsmb_<?lsmb dbname ?>__pricegroup_edit');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (92, 'allow', 'lsmb_<?lsmb dbname ?>__pricegroup_edit');
 
@@ -855,8 +776,6 @@ WITH INHERIT NOLOGIN;
 
 GRANT UPDATE ON parts TO "lsmb_<?lsmb dbname ?>__assembly_stock";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (77, 'allow', 'lsmb_<?lsmb dbname ?>__assembly_stock');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (84, 'allow', 'lsmb_<?lsmb dbname ?>__assembly_stock');
 
@@ -868,8 +787,6 @@ IN ROLE "lsmb_<?lsmb dbname ?>__sales_order_list";
 GRANT INSERT ON inventory TO "lsmb_<?lsmb dbname ?>__inventory_ship";
 GRANT ALL ON inventory_entry_id_seq TO "lsmb_<?lsmb dbname ?>__inventory_ship";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (63, 'allow', 'lsmb_<?lsmb dbname ?>__inventory_ship');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (64, 'allow', 'lsmb_<?lsmb dbname ?>__inventory_ship');
 
@@ -881,8 +798,6 @@ IN ROLE "lsmb_<?lsmb dbname ?>__purchase_order_list";
 GRANT INSERT ON inventory TO "lsmb_<?lsmb dbname ?>__inventory_receive";
 GRANT ALL ON inventory_entry_id_seq TO "lsmb_<?lsmb dbname ?>__inventory_receive";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (63, 'allow', 'lsmb_<?lsmb dbname ?>__inventory_receive');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (65, 'allow', 'lsmb_<?lsmb dbname ?>__inventory_receive');
 
@@ -893,8 +808,6 @@ WITH INHERIT NOLOGIN;
 GRANT INSERT ON inventory TO "lsmb_<?lsmb dbname ?>__inventory_transfer";
 GRANT ALL ON inventory_entry_id_seq TO "lsmb_<?lsmb dbname ?>__inventory_transfer";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (63, 'allow', 'lsmb_<?lsmb dbname ?>__inventory_transfer');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (66, 'allow', 'lsmb_<?lsmb dbname ?>__inventory_transfer');
 
@@ -904,10 +817,6 @@ WITH INHERIT NOLOGIN;
 GRANT INSERT ON warehouse TO "lsmb_<?lsmb dbname ?>__warehouse_create";
 GRANT ALL ON warehouse_id_seq TO "lsmb_<?lsmb dbname ?>__warehouse_create";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (128, 'allow', 'lsmb_<?lsmb dbname ?>__warehouse_create');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (141, 'allow', 'lsmb_<?lsmb dbname ?>__warehouse_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (142, 'allow', 'lsmb_<?lsmb dbname ?>__warehouse_create');
 
@@ -917,10 +826,6 @@ WITH INHERIT NOLOGIN;
 
 GRANT UPDATE ON warehouse TO "lsmb_<?lsmb dbname ?>__warehouse_edit";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (128, 'allow', 'lsmb_<?lsmb dbname ?>__warehouse_edit');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (141, 'allow', 'lsmb_<?lsmb dbname ?>__warehouse_edit');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (143, 'allow', 'lsmb_<?lsmb dbname ?>__warehouse_edit');
 
@@ -946,15 +851,11 @@ GRANT INSERT ON acc_trans TO "lsmb_<?lsmb dbname ?>__gl_transaction_create";
 GRANT ALL ON id TO "lsmb_<?lsmb dbname ?>__gl_transaction_create";
 GRANT ALL ON acc_trans_entry_id_seq TO "lsmb_<?lsmb dbname ?>__gl_transaction_create";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (73, 'allow', 'lsmb_<?lsmb dbname ?>__gl_transaction_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (74, 'allow', 'lsmb_<?lsmb dbname ?>__gl_transaction_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (75, 'allow', 'lsmb_<?lsmb dbname ?>__gl_transaction_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (35, 'allow', 'lsmb_<?lsmb dbname ?>__gl_transaction_create');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (40, 'allow', 'lsmb_<?lsmb dbname ?>__gl_transaction_create');
 
 
@@ -976,8 +877,6 @@ IN ROLE "lsmb_<?lsmb dbname ?>__ar_transaction_list",
 GRANT SELECT ON gl, acc_trans, account_checkpoint 
 TO "lsmb_<?lsmb dbname ?>__gl_reports";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (73, 'allow', 'lsmb_<?lsmb dbname ?>__gl_reports');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (76, 'allow', 'lsmb_<?lsmb dbname ?>__gl_reports');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
@@ -994,8 +893,6 @@ TO "lsmb_<?lsmb dbname ?>__yearend_run";
 
 GRANT ALL ON account_checkpoint_id_seq TO "lsmb_<?lsmb dbname ?>__yearend_run";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (128, 'allow', 'lsmb_<?lsmb dbname ?>__yearend_run');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (132, 'allow', 'lsmb_<?lsmb dbname ?>__yearend_run');
 
@@ -1022,8 +919,6 @@ WITH INHERIT NOLOGIN;
 GRANT INSERT ON project TO "lsmb_<?lsmb dbname ?>__project_create";
 GRANT ALL ON project_id_seq TO "lsmb_<?lsmb dbname ?>__project_create";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (98, 'allow', 'lsmb_<?lsmb dbname ?>__project_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (99, 'allow', 'lsmb_<?lsmb dbname ?>__project_create');
 
@@ -1033,10 +928,6 @@ WITH INHERIT NOLOGIN;
 
 GRANT UPDATE ON project TO "lsmb_<?lsmb dbname ?>__project_edit";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (98, 'allow', 'lsmb_<?lsmb dbname ?>__project_edit');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (103, 'allow', 'lsmb_<?lsmb dbname ?>__project_edit');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (104, 'allow', 'lsmb_<?lsmb dbname ?>__project_edit');
 
@@ -1048,13 +939,9 @@ IN ROLE "lsmb_<?lsmb dbname ?>__contact_read";
 GRANT INSERT, UPDATE ON jcitems TO "lsmb_<?lsmb dbname ?>__project_timecard_add";
 GRANT ALL ON jcitems_id_seq TO "lsmb_<?lsmb dbname ?>__project_timecard_add";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (98, 'allow', 'lsmb_<?lsmb dbname ?>__project_timecard_add');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (100, 'allow', 'lsmb_<?lsmb dbname ?>__project_timecard_add');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (103, 'allow', 'lsmb_<?lsmb dbname ?>__project_timecard_add');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (106, 'allow', 'lsmb_<?lsmb dbname ?>__project_timecard_add');
 
 CREATE ROLE "lsmb_<?lsmb dbname ?>__project_timecard_list"
@@ -1063,10 +950,6 @@ IN ROLE "lsmb_<?lsmb dbname ?>__contact_read";
 
 GRANT SELECT ON jcitems TO "lsmb_<?lsmb dbname ?>__project_timecard_list";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (98, 'allow', 'lsmb_<?lsmb dbname ?>__project_timecard_list');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (103, 'allow', 'lsmb_<?lsmb dbname ?>__project_timecard_list');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (106, 'allow', 'lsmb_<?lsmb dbname ?>__project_timecard_list');
 
@@ -1087,10 +970,6 @@ WITH INHERIT NOLOGIN
 IN ROLE "lsmb_<?lsmb dbname ?>__orders_generate",
 "lsmb_<?lsmb dbname ?>__project_timecard_list";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (98, 'allow', 'lsmb_<?lsmb dbname ?>__project_order_generate');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (101, 'allow', 'lsmb_<?lsmb dbname ?>__project_order_generate');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (102, 'allow', 'lsmb_<?lsmb dbname ?>__project_order_generate');
 
@@ -1099,10 +978,6 @@ CREATE ROLE "lsmb_<?lsmb dbname ?>__orders_sales_to_purchase"
 WITH INHERIT NOLOGIN
 IN ROLE "lsmb_<?lsmb dbname ?>__orders_generate";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (50, 'allow', 'lsmb_<?lsmb dbname ?>__orders_sales_to_purchase');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (56, 'allow', 'lsmb_<?lsmb dbname ?>__orders_sales_to_purchase');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (57, 'allow', 'lsmb_<?lsmb dbname ?>__orders_sales_to_purchase');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
@@ -1113,8 +988,6 @@ CREATE ROLE "lsmb_<?lsmb dbname ?>__orders_purchase_consolidate"
 WITH INHERIT NOLOGIN
 IN ROLE "lsmb_<?lsmb dbname ?>__orders_generate";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (50, 'allow', 'lsmb_<?lsmb dbname ?>__orders_purchase_consolidate');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (60, 'allow', 'lsmb_<?lsmb dbname ?>__orders_purchase_consolidate');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
@@ -1125,8 +998,6 @@ CREATE ROLE "lsmb_<?lsmb dbname ?>__orders_sales_consolidate"
 WITH INHERIT NOLOGIN
 IN ROLE "lsmb_<?lsmb dbname ?>__orders_generate";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (50, 'allow', 'lsmb_<?lsmb dbname ?>__orders_sales_consolidate');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (60, 'allow', 'lsmb_<?lsmb dbname ?>__orders_sales_consolidate');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
@@ -1147,8 +1018,6 @@ IN ROLE "lsmb_<?lsmb dbname ?>__gl_reports";
 
 GRANT select ON yearend TO "lsmb_<?lsmb dbname ?>__financial_reports";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (109, 'allow', 'lsmb_<?lsmb dbname ?>__financial_reports');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (110, 'allow', 'lsmb_<?lsmb dbname ?>__financial_reports');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
@@ -1173,8 +1042,6 @@ values (115, 'allow', 'lsmb_<?lsmb dbname ?>__print_jobs_list');
 CREATE ROLE "lsmb_<?lsmb dbname ?>__print_jobs_list"
 WITH INHERIT NOLOGIN;
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (116, 'allow', 'lsmb_<?lsmb dbname ?>__print_jobs_list');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (117, 'allow', 'lsmb_<?lsmb dbname ?>__print_jobs_list');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
@@ -1224,8 +1091,6 @@ SELECT id, 'allow', 'lsmb_<?lsmb dbname ?>__tax_form_save'
 CREATE ROLE "lsmb_<?lsmb dbname ?>__system_settings_list"
 WITH INHERIT NOLOGIN;
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (128, 'allow', 'lsmb_<?lsmb dbname ?>__system_settings_list');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (129, 'allow', 'lsmb_<?lsmb dbname ?>__system_settings_list');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
@@ -1241,8 +1106,6 @@ WITH INHERIT NOLOGIN;
 
 GRANT INSERT, UPDATE ON tax TO "lsmb_<?lsmb dbname ?>__taxes_set";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (128, 'allow', 'lsmb_<?lsmb dbname ?>__taxes_set');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (130, 'allow', 'lsmb_<?lsmb dbname ?>__taxes_set');
 
@@ -1261,10 +1124,6 @@ GRANT INSERT ON account_link TO "lsmb_<?lsmb dbname ?>__account_create";
 -- account_link no longer appears to have a sequence and references account(id)
 --GRANT ALL ON account_link_id_seq TO "lsmb_<?lsmb dbname ?>__account_create";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (128, 'allow', 'lsmb_<?lsmb dbname ?>__account_create');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (136, 'allow', 'lsmb_<?lsmb dbname ?>__account_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (137, 'allow', 'lsmb_<?lsmb dbname ?>__account_create');
 
@@ -1275,10 +1134,6 @@ WITH INHERIT NOLOGIN;
 GRANT ALL ON account, account_heading, account_link, cr_coa_to_account 
 TO "lsmb_<?lsmb dbname ?>__account_edit";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (128, 'allow', 'lsmb_<?lsmb dbname ?>__account_edit');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (136, 'allow', 'lsmb_<?lsmb dbname ?>__account_edit');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (138, 'allow', 'lsmb_<?lsmb dbname ?>__account_edit');
 
@@ -1297,10 +1152,6 @@ WITH INHERIT NOLOGIN;
 
 GRANT INSERT ON gifi TO "lsmb_<?lsmb dbname ?>__gifi_create";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (128, 'allow', 'lsmb_<?lsmb dbname ?>__gifi_create');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (136, 'allow', 'lsmb_<?lsmb dbname ?>__gifi_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (139, 'allow', 'lsmb_<?lsmb dbname ?>__gifi_create');
 
@@ -1310,10 +1161,6 @@ WITH INHERIT NOLOGIN;
 
 GRANT UPDATE ON gifi TO "lsmb_<?lsmb dbname ?>__gifi_edit";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (128, 'allow', 'lsmb_<?lsmb dbname ?>__gifi_edit');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (136, 'allow', 'lsmb_<?lsmb dbname ?>__gifi_edit');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (140, 'allow', 'lsmb_<?lsmb dbname ?>__gifi_edit');
 
@@ -1332,10 +1179,6 @@ WITH INHERIT NOLOGIN;
 GRANT INSERT ON department TO "lsmb_<?lsmb dbname ?>__department_create";
 GRANT ALL ON department_id_seq TO "lsmb_<?lsmb dbname ?>__department_create";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (128, 'allow', 'lsmb_<?lsmb dbname ?>__department_create');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (144, 'allow', 'lsmb_<?lsmb dbname ?>__department_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (145, 'allow', 'lsmb_<?lsmb dbname ?>__department_create');
 
@@ -1345,10 +1188,6 @@ WITH INHERIT NOLOGIN;
 
 GRANT UPDATE ON department TO "lsmb_<?lsmb dbname ?>__department_edit";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (128, 'allow', 'lsmb_<?lsmb dbname ?>__department_edit');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (144, 'allow', 'lsmb_<?lsmb dbname ?>__department_edit');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (146, 'allow', 'lsmb_<?lsmb dbname ?>__department_edit');
 
@@ -1364,10 +1203,6 @@ WITH INHERIT NOLOGIN;
 GRANT INSERT ON business TO "lsmb_<?lsmb dbname ?>__business_type_create";
 GRANT ALL ON business_id_seq TO "lsmb_<?lsmb dbname ?>__business_type_create";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (128, 'allow', 'lsmb_<?lsmb dbname ?>__business_type_create');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (147, 'allow', 'lsmb_<?lsmb dbname ?>__business_type_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (148, 'allow', 'lsmb_<?lsmb dbname ?>__business_type_create');
 
@@ -1377,10 +1212,6 @@ WITH INHERIT NOLOGIN;
 
 GRANT UPDATE, DELETE ON business TO "lsmb_<?lsmb dbname ?>__business_type_edit";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (128, 'allow', 'lsmb_<?lsmb dbname ?>__business_type_edit');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (147, 'allow', 'lsmb_<?lsmb dbname ?>__business_type_edit');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (149, 'allow', 'lsmb_<?lsmb dbname ?>__business_type_edit');
 
@@ -1395,10 +1226,6 @@ WITH INHERIT NOLOGIN;
 
 GRANT INSERT ON sic TO "lsmb_<?lsmb dbname ?>__sic_create";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (128, 'allow', 'lsmb_<?lsmb dbname ?>__sic_create');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (153, 'allow', 'lsmb_<?lsmb dbname ?>__sic_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (154, 'allow', 'lsmb_<?lsmb dbname ?>__sic_create');
 
@@ -1408,10 +1235,6 @@ WITH INHERIT NOLOGIN;
 
 GRANT UPDATE ON sic TO "lsmb_<?lsmb dbname ?>__sic_edit";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (128, 'allow', 'lsmb_<?lsmb dbname ?>__sic_edit');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (153, 'allow', 'lsmb_<?lsmb dbname ?>__sic_edit');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (155, 'allow', 'lsmb_<?lsmb dbname ?>__sic_edit');
 
@@ -1428,10 +1251,6 @@ WITH INHERIT NOLOGIN;
 
 -- TODO Add db permissions as templates get moved into db.
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (128, 'allow', 'lsmb_<?lsmb dbname ?>__template_edit');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (156, 'allow', 'lsmb_<?lsmb dbname ?>__template_edit');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (157, 'allow', 'lsmb_<?lsmb dbname ?>__template_edit');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
@@ -1463,8 +1282,6 @@ values (170, 'allow', 'lsmb_<?lsmb dbname ?>__template_edit');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (171, 'allow', 'lsmb_<?lsmb dbname ?>__template_edit');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (172, 'allow', 'lsmb_<?lsmb dbname ?>__template_edit');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (173, 'allow', 'lsmb_<?lsmb dbname ?>__template_edit');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (174, 'allow', 'lsmb_<?lsmb dbname ?>__template_edit');
@@ -1495,8 +1312,6 @@ values (186, 'allow', 'lsmb_<?lsmb dbname ?>__template_edit');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (187, 'allow', 'lsmb_<?lsmb dbname ?>__template_edit');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (188, 'allow', 'lsmb_<?lsmb dbname ?>__template_edit');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (189, 'allow', 'lsmb_<?lsmb dbname ?>__template_edit');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (190, 'allow', 'lsmb_<?lsmb dbname ?>__template_edit');
@@ -1569,10 +1384,6 @@ WITH INHERIT NOLOGIN;
 
 GRANT INSERT ON language TO "lsmb_<?lsmb dbname ?>__language_create";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (128, 'allow', 'lsmb_<?lsmb dbname ?>__language_create');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (150, 'allow', 'lsmb_<?lsmb dbname ?>__language_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (151, 'allow', 'lsmb_<?lsmb dbname ?>__language_create');
 
@@ -1582,10 +1393,6 @@ WITH INHERIT NOLOGIN;
 
 GRANT UPDATE ON language TO "lsmb_<?lsmb dbname ?>__language_edit";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (128, 'allow', 'lsmb_<?lsmb dbname ?>__language_edit');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (150, 'allow', 'lsmb_<?lsmb dbname ?>__language_edit');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (152, 'allow', 'lsmb_<?lsmb dbname ?>__language_edit');
 
@@ -1596,10 +1403,6 @@ WITH INHERIT NOLOGIN;
 GRANT ALL ON parts_translation 
 TO "lsmb_<?lsmb dbname ?>__part_translation_create";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (77, 'allow', 'lsmb_<?lsmb dbname ?>__part_translation_create');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (95, 'allow', 'lsmb_<?lsmb dbname ?>__part_translation_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (96, 'allow', 'lsmb_<?lsmb dbname ?>__part_translation_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
@@ -1612,10 +1415,6 @@ WITH INHERIT NOLOGIN;
 GRANT ALL ON project_translation 
 TO "lsmb_<?lsmb dbname ?>__project_translation_create";
 
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (98, 'allow', 'lsmb_<?lsmb dbname ?>__project_translation_create');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (107, 'allow', 'lsmb_<?lsmb dbname ?>__project_translation_create');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (108, 'allow', 'lsmb_<?lsmb dbname ?>__project_translation_create');
 
@@ -1625,10 +1424,6 @@ WITH INHERIT NOLOGIN;
 GRANT ALL ON partsgroup_translation
 TO "lsmb_<?lsmb dbname ?>__partsgroup_translation_create";
 INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (98, 'allow', 'lsmb_<?lsmb dbname ?>__partsgroup_translation_create');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (107, 'allow', 'lsmb_<?lsmb dbname ?>__partsgroup_translation_create');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (108, 'allow', 'lsmb_<?lsmb dbname ?>__partsgroup_translation_create');
 
 
@@ -1774,6 +1569,4 @@ TO "lsmb_<?lsmb dbname ?>__voucher_delete";
 INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (191, 'allow', 'public');
 INSERT INTO menu_acl (node_id, acl_type, role_name)
-values (192, 'allow', 'public');
-INSERT INTO menu_acl (node_id, acl_type, role_name)
 values (193, 'allow', 'public');
